/********************************************
  网页获取摇杆模拟量值实例程序-Ethernet库
  
  使用Arduino控制板、Ethernet Shield扩展板、Input Shield扩展板
  浏览器形式获取摇杆水平方向、垂直方向模拟量数值
  IP地址：192.168.0.123
  MAC地址：0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED
  网关：192.168.0.1
  子网掩码：255.255.255.0

  created 2011
  by Nille 
  Email：chenille@126.com
 
  This example code is in the public domain.
 *********************************************/

// 包含SPI库头文件和Ethernet库头文件
#include <SPI.h>
#include <Ethernet.h>

// 定义两个数组用来存储MAC地址和IP地址.
byte mac[] = {0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED };
byte ip[] = {192,168,0, 123 };
byte gateway[] = {192,168,0, 1};
byte subnet[] = {255, 255, 255, 0};

// 初始化Ethernet server 库(port 80 is default for HTTP):
EthernetServer server(80);

/**********************************************
    初始化部分——setup函数
**********************************************/
void setup()
{
  //SPI接口初始化
  SPI.begin();
  SPI.setBitOrder(MSBFIRST);
  SPI.setDataMode(SPI_MODE0);
  
  //由于W5100的外部中断使用引脚3，此处将引脚3置为输出，同时输出高电平
  pinMode(3, OUTPUT);
  digitalWrite(3, HIGH);

  // 初始化网络端口
  Ethernet.begin(mac, ip, gateway, subnet);
  
  server.begin();
}

/**********************************************
    执行部分——loop函数
**********************************************/
void loop()
{
  //侦听
  EthernetClient client = server.available();
  if (client) 
  {
    // an http request ends with a blank line
    boolean currentLineIsBlank = true;
    while (client.connected()) 
    {
      if (client.available()) 
      {
        char c = client.read();
        
        if (c == '\n' && currentLineIsBlank)
        {
          // send a standard http response header
          client.println("HTTP/1.1 200 OK");
          client.println("Content-Type: text/html");
          client.println();

          //输出水平方向模拟量数值
          client.print("horizontal:");
          //水平方向使用的是模拟口1
          client.print(analogRead(1));
          //输出一个网页格式中的回车
          client.println("<br />");
                    
          //输出垂直方向模拟量数值
          client.print("vertical:");
          //垂直方向使用的是模拟口0
          client.print(analogRead(0));
                   
          break;
        }

        if (c == '\n') 
        {
           // you're starting a new line
           currentLineIsBlank = true;
        } 
        else if (c != '\r') 
        {
          // you've gotten a character on the current line
          currentLineIsBlank = false;
        }
      }
    }
    // 延时等待浏览器接收数据
    delay(1);
    // 关闭连接
    client.stop();
  }
}
