/********************************************
RGB LED Module上的LED逐个点亮、熄灭实例程序2
  
每个LED灯每次点亮时间0.5秒。先后显示蓝、绿、红3种颜色

引脚使用情况：
------------------------
 ARDUINO         13     |-> SCLK (pin 25) 
                 12	|
                 11	|-> SIN (pin 26)
                 10	|-> BLANK (pin 23)
                  9	|-> XLAT (pin 24)
                  8	|
			|
                  7	|
                  6	|
                  5	|
                  4	|
                  3	|-> GSCLK (pin 18)
                  2	|
                  1	|
                  0	|
------------------------ 

TLC5940引脚定义：
         -------TLC5940-----
   OUT1	|1                28| OUT0
   OUT2	|2                27|-> VPRG (GND)
   OUT3	|3                26|-> SIN (pin 11)
   OUT4	|4                25|-> SCLK (pin 13)
   OUT5	|5                24|-> XLAT (pin 9)
   OUT6	|6                23|-> BLANK (pin 10)
   OUT7	|7                22|-> GND
   OUT8	|8                21|-> VCC (+5V)
   OUT9	|9                20|-> IREF
  OUT10	|10               19|-> DCPRG (+5V)
  OUT11	|11               18|-> GSCLK (pin 3)
  OUT12	|12               17|-> SOUT
  OUT13	|13               16|-> XERR
  OUT14	|14               15| OUT15
         -------------------

created 2011
by Nille 
Email：chenille@126.com
*********************************************/

#define 	GSCLK 	3		//GSCLK占用引脚3
#define	        XLAT 	9		//XLAT占用引脚9
#define 	BLANK 	10		//BLANK占用引脚10
#define 	SCLK 	13		//SCLK占用引脚13
#define 	SIN	11		//SIN占用引脚11


/**********************************************
 XLAT产生一个脉冲
函数功能：XLAT产生一个脉冲，用于锁存一组数据
入口参数：无
出口参数：无
**********************************************/
void XLATPulses()
{
  digitalWrite(XLAT, HIGH);	//XLAT置高
  delayMicroseconds(10);
  digitalWrite(XLAT, LOW);	//XLAT置低
  delayMicroseconds(10);
}


/**********************************************
 SCLK产生一个脉冲
函数功能：SCLK产生一个脉冲，用于传输1bit数据
入口参数：无
出口参数：无
**********************************************/
void SCLKPulses()
{
  digitalWrite(SCLK, HIGH);	//SCLK置高
  delayMicroseconds(10);
  digitalWrite(SCLK, LOW);	//SCLK置低
  delayMicroseconds(10);
}

/**********************************************
 点亮一个通道的LED灯
函数功能：点亮指定通道的LED灯
入口参数：channel——通道值，参数范围值为0至47
出口参数：无
**********************************************/
void SetChannel(int channel)
{
	//TLC5940的每一个通道为12位的PWM，48个通道的数据量是48×12 = 576bit
	//每一个通道含12bit数据
	for(int i = 0 ; i<576 ; i++)	
	{
		//根据通道值决定每bit数据置高或置低
		if ( (i> (channel*12) ) && ( i < ( (channel+1)*12-1) ) )
		digitalWrite(SIN, HIGH);
  		else
  		digitalWrite(SIN, LOW);
		delayMicroseconds(10);
				
		//每1bit置位完成后输出一个SCLK脉冲
		SCLKPulses ();
	}
}

/**********************************************
    初始化部分——setup函数
**********************************************/
void setup() 
{                
  //将控制引脚置位输出
  pinMode(SCLK, OUTPUT); 
  pinMode(SIN, OUTPUT);
  pinMode(BLANK, OUTPUT);
  pinMode(XLAT, OUTPUT);
  
  //依据图5.31 TLC5940NT PWM LED驱动芯片的控制时序图设置引脚初始值
  digitalWrite(BLANK,LOW);
  digitalWrite(XLAT,LOW);
  digitalWrite(SCLK,LOW);
  
  //GSCLK输出PWM脉冲，用于TLC5940芯片输出PWM信号的参考时钟
  analogWrite(GSCLK,127);  
}
	

/**********************************************
    执行部分——loop函数
**********************************************/
void loop()
{
	for(int j = 0 ; j < 48 ; j ++)		//依次点亮48个通道的LED灯
	{
		digitalWrite(BLANK,HIGH);	//BLANK置高，开始传输数据
		SetChannel(j);	//循环点亮LED
		XLATPulses();	//XLAT脉冲
	
		digitalWrite(BLANK,LOW);	//BLANK置低，数据传输结束
		delay(500);		//每个LED灯每次点亮时间0.5秒
	}
}
